Restoration
-------------

Restorations module is the place various image restorations methods implemented. Denoising,
deconvolution and so. One can use object-oriented restoration API calls or procedural
restoration API calls Aydin provides.


.. toctree::
   :maxdepth: 1

   Denoise <restorations/denoise_restoration>
   Deconvolve <restorations/deconvolve_restoration>

